// The package of this claz.
package kirk.gui.dialog;

// Import the GUI and event stuff.
import java.awt.*;
import java.awt.event.*;

import kirk.gui.WindowCloser;
import kirk.gui.layout.*;

/**
 * This class is an abstract class that other <code>Dialog</code>s can extend to save
 * on some behaviour, like closing the <code>Window</code>. Also provided is action
 * listening for one <code>Button</code>, so if you add a <code>Button</code> and set
 * this class as its <code>ActionListener</code>, then that <code>Button</code> will
 * close the <code>Dialog</code>.
 * 
 * The constructor initialses some things for you:
 * This class uses <code>CenteredLineLayout</code>,
 * it cannot be resized by the user,
 * it is modal,
 * it will appear in the middle of the screen,
 * it will be closed by <code>WindowCloser</code>.
 * 
 * It also implements <code>ActionListener</code>, and it already implements
 * <code>actionPerformed</code> as well, however you can override it if you wish,
 * or call it by using <code>super()</code>.
 *
 * @author Berend Wouda
 * @version 1
 */
public abstract class PopupDialog extends Dialog implements ActionListener {
	/**
	 * Constructs a new <code>PopupDialog</code>.
	 * 
	 * @param owner The owner of this <code>Dialog</code>.
	 * @param title The title of this <code>Dialog</code>.
	 * @param width The width of this <code>Dialog</code> in pixels.
	 * @param width The height of this <code>Dialog</code> in pixels.
	 */
	public PopupDialog(Frame owner, String title, int width, int height) {
		// Call the supercontructor, with owner, the passed title and true for
		// "modal" (blocks input to the owner frame while this Dialog is open).
		super(owner, title, true);
		
		// Set the layout to CenteredLineLayout.
		setLayout(new CenteredLineLayout());
		
		// Set the size to the passed size.
		setSize(width, height);
		
		// Set it so that the user cannot resize the window.
		setResizable(false);
		
		// Set the location (in the middle of the screen).
		Dimension screensize = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((screensize.width - getWidth()) / 2, (screensize.height - getHeight())/ 2);
		
		// This screen has to be closable too, you know.
		addWindowListener(new WindowCloser());
	}


	/**
	 * Closes this <code>Dialog</code>.
	 * 
	 * @param event The unused standard passed <code>ActionEvent</code>.
	 */
	public void actionPerformed(ActionEvent event) {
		// There is only one button that can generate an action event.
		// That means this window can be closed.
		// Hide this Dialog.
		hide();
		
		// Dump this Dialog.
		dispose();
	}
}